Aplanat
=======

Aplanat provides a wrappers around the bokeh library to simplify plotting
of common plots.

Installation
------------

Aplanat is easily installed in the standard python tradition:

    git clone --recursive https://github.com/epi2me-labs/aplanat.git
    cd aplanat
    pip install -r requirements.txt
    python setup.py install

